module.exports = {
	description: 'external paths (#754)',
	options: {
		output: { paths: { foo: 'https://unpkg.com/foo' } }
	}
};
